% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/FSFDR.R
\name{FSFDR.arbidept.cv}
\alias{FSFDR.arbidept.cv}
\title{Critical Values for Fixed Sequence FDR Controlling Procedure under Arbitrary Dependence}
\usage{
FSFDR.arbidept.cv(p, k=1, alpha = 0.05, make.decision = TRUE)
}
\arguments{
\item{p}{numeric vector of p-values (possibly with \code{\link[base]{NA}}s). Any other R is coerced by \code{\link[base]{as.numeric}}. Same as in \code{\link[stats]{p.adjust}}.}

\item{k}{pre-specified number of acceptances allowed in the testing procedure (cannot exceed the length of \code{p})}

\item{alpha}{significant level used to calculate the critical values to make decisions, the default value is 0.05.}

\item{make.decision}{logical; if  \code{TRUE} (default), then the output include the decision rules compared adjusted p-values with significant level \eqn{alpha}}
}
\value{
A numeric vector of the critical values (of the same length as \code{p}) if  \code{make.decision = FALSE}, or  a data frame including original p-values, critical values and decision rules if \code{make.decision = TRUE}.
}
\description{
Given a set of pre-ordered p-values and accuracy for the result, return the corresponding critical values using the generalized fixed sequence FDR controlling procedure under arbitrary dependence (See Theorem 3.1 and 4.1 in Lynch et al. (2016)). The function also provides an option to make decisions given a pre-specified significant level \eqn{\alpha}.
}
\examples{
## generate a pre-ordered pvalue vector for 50 hypotheses, where 80\% are true nulls
set.seed(1234); m <- 50; pi0 <- 0.8; m0 <- m*pi0; m1 <- m-m0
mu <- c(4*0.9^(1:m1), rep(0,m0))
Zstat <- rnorm(n = m, mean = mu)
Pval <- 1-pnorm(Zstat)
## conventional fixed sequence procedure
FSFDR.arbidept.cv(p = Pval, alpha = 0.05)
## generalized fixed sequence procedure allowing stop at 5th acceptance
FSFDR.arbidept.cv(p = Pval, alpha = 0.05, k=5)
}
\author{
Yalin Zhu
}
\references{
Lynch, G., Guo, W., Sarkar, S. K., & Finner, H. (2016).
 The Control of the False Discovery Rate in Fixed Sequence Multiple Testing.
 \emph{arXiv preprint} arXiv:1611.03146.
}
\seealso{
\code{\link{FSFWER.arbidept.cv}}  for fixed sequence FWER controlling procedures.
}

